<a id="mypy-boto3-quicksight"></a>

# mypy-boto3-quicksight

[![PyPI - mypy-boto3-quicksight](https://img.shields.io/pypi/v/mypy-boto3-quicksight.svg?color=blue)](https://pypi.org/project/mypy-boto3-quicksight)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-quicksight.svg?color=blue)](https://pypi.org/project/mypy-boto3-quicksight)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-quicksight?color=blue)](https://pypistats.org/packages/mypy-boto3-quicksight)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.QuickSight 1.26.18](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/quicksight.html#QuickSight)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.11.11](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-quicksight docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_quicksight/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-quicksight](#mypy-boto3-quicksight)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `QuickSight`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `boto3-stubs` for `QuickSight` service.

```bash
# install with boto3 type annotations
python -m pip install 'boto3-stubs[quicksight]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'boto3-stubs-lite[quicksight]'


# standalone installation
python -m pip install mypy-boto3-quicksight
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y mypy-boto3-quicksight
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto3-stubs[quicksight]` in your environment:

```bash
python -m pip install 'boto3-stubs[quicksight]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `boto3-stubs-lite[quicksight]` in your environment:

```bash
python -m pip install 'boto3-stubs-lite[quicksight]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `boto3-stubs` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `boto3-stubs` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[quicksight]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed `boto3-stubs`

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `boto3-stubs[quicksight]` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[quicksight]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto3-stubs[quicksight]` in your environment:

```bash
python -m pip install 'boto3-stubs[quicksight]'`
```

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `boto3-stubs[quicksight]` in your environment:

```bash
python -m pip install 'boto3-stubs[quicksight]'
```

Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`QuickSightClient` provides annotations for `boto3.client("quicksight")`.

```python
from boto3.session import Session

from mypy_boto3_quicksight import QuickSightClient

client: QuickSightClient = Session().client("quicksight")

# now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_quicksight.paginator` module contains type annotations for all
paginators.

```python
from boto3.session import Session

from mypy_boto3_quicksight import QuickSightClient
from mypy_boto3_quicksight.paginator import (
    ListAnalysesPaginator,
    ListDashboardVersionsPaginator,
    ListDashboardsPaginator,
    ListDataSetsPaginator,
    ListDataSourcesPaginator,
    ListIngestionsPaginator,
    ListNamespacesPaginator,
    ListTemplateAliasesPaginator,
    ListTemplateVersionsPaginator,
    ListTemplatesPaginator,
    ListThemeVersionsPaginator,
    ListThemesPaginator,
    SearchAnalysesPaginator,
    SearchDashboardsPaginator,
    SearchDataSetsPaginator,
    SearchDataSourcesPaginator,
)

client: QuickSightClient = Session().client("quicksight")

# Explicit type annotations are optional here
# Types should be correctly discovered by mypy and IDEs
list_analyses_paginator: ListAnalysesPaginator = client.get_paginator("list_analyses")
list_dashboard_versions_paginator: ListDashboardVersionsPaginator = client.get_paginator(
    "list_dashboard_versions"
)
list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
list_data_sets_paginator: ListDataSetsPaginator = client.get_paginator("list_data_sets")
list_data_sources_paginator: ListDataSourcesPaginator = client.get_paginator("list_data_sources")
list_ingestions_paginator: ListIngestionsPaginator = client.get_paginator("list_ingestions")
list_namespaces_paginator: ListNamespacesPaginator = client.get_paginator("list_namespaces")
list_template_aliases_paginator: ListTemplateAliasesPaginator = client.get_paginator(
    "list_template_aliases"
)
list_template_versions_paginator: ListTemplateVersionsPaginator = client.get_paginator(
    "list_template_versions"
)
list_templates_paginator: ListTemplatesPaginator = client.get_paginator("list_templates")
list_theme_versions_paginator: ListThemeVersionsPaginator = client.get_paginator(
    "list_theme_versions"
)
list_themes_paginator: ListThemesPaginator = client.get_paginator("list_themes")
search_analyses_paginator: SearchAnalysesPaginator = client.get_paginator("search_analyses")
search_dashboards_paginator: SearchDashboardsPaginator = client.get_paginator("search_dashboards")
search_data_sets_paginator: SearchDataSetsPaginator = client.get_paginator("search_data_sets")
search_data_sources_paginator: SearchDataSourcesPaginator = client.get_paginator(
    "search_data_sources"
)
```

<a id="literals"></a>

### Literals

`mypy_boto3_quicksight.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_quicksight.literals import (
    AnalysisErrorTypeType,
    AnalysisFilterAttributeType,
    AnchorOptionType,
    ArcThicknessOptionsType,
    ArcThicknessType,
    AssignmentStatusType,
    AuthenticationMethodOptionType,
    AxisBindingType,
    BarChartOrientationType,
    BarsArrangementType,
    BaseMapStyleTypeType,
    BoxPlotFillStyleType,
    CategoricalAggregationFunctionType,
    CategoryFilterMatchOperatorType,
    CategoryFilterSelectAllOptionsType,
    ColorFillTypeType,
    ColumnDataTypeType,
    ColumnRoleType,
    ColumnTagNameType,
    ComparisonMethodType,
    ConditionalFormattingIconDisplayOptionType,
    ConditionalFormattingIconSetTypeType,
    CrossDatasetTypesType,
    CustomContentImageScalingConfigurationType,
    CustomContentTypeType,
    DashboardBehaviorType,
    DashboardErrorTypeType,
    DashboardFilterAttributeType,
    DashboardUIStateType,
    DataLabelContentType,
    DataLabelOverlapType,
    DataLabelPositionType,
    DataSetFilterAttributeType,
    DataSetImportModeType,
    DataSourceErrorInfoTypeType,
    DataSourceFilterAttributeType,
    DataSourceTypeType,
    DateAggregationFunctionType,
    EditionType,
    EmbeddingIdentityTypeType,
    FileFormatType,
    FilterNullOptionType,
    FilterOperatorType,
    FilterVisualScopeType,
    FolderFilterAttributeType,
    FolderTypeType,
    FontDecorationType,
    FontStyleType,
    FontWeightNameType,
    ForecastComputationSeasonalityType,
    FunnelChartMeasureDataLabelStyleType,
    GeoSpatialCountryCodeType,
    GeoSpatialDataRoleType,
    GeospatialSelectedPointStyleType,
    GroupFilterAttributeType,
    GroupFilterOperatorType,
    HistogramBinTypeType,
    HorizontalTextAlignmentType,
    IconType,
    IdentityStoreType,
    IdentityTypeType,
    IngestionErrorTypeType,
    IngestionRequestSourceType,
    IngestionRequestTypeType,
    IngestionStatusType,
    IngestionTypeType,
    InputColumnDataTypeType,
    JoinTypeType,
    LayoutElementTypeType,
    LegendPositionType,
    LineChartLineStyleType,
    LineChartMarkerShapeType,
    LineChartTypeType,
    LineInterpolationType,
    ListAnalysesPaginatorName,
    ListDashboardVersionsPaginatorName,
    ListDashboardsPaginatorName,
    ListDataSetsPaginatorName,
    ListDataSourcesPaginatorName,
    ListIngestionsPaginatorName,
    ListNamespacesPaginatorName,
    ListTemplateAliasesPaginatorName,
    ListTemplateVersionsPaginatorName,
    ListTemplatesPaginatorName,
    ListThemeVersionsPaginatorName,
    ListThemesPaginatorName,
    MapZoomModeType,
    MaximumMinimumComputationTypeType,
    MemberTypeType,
    MissingDataTreatmentOptionType,
    NamespaceErrorTypeType,
    NamespaceStatusType,
    NegativeValueDisplayModeType,
    NumberScaleType,
    NumericEqualityMatchOperatorType,
    NumericFilterSelectAllOptionsType,
    NumericSeparatorSymbolType,
    OtherCategoriesType,
    PanelBorderStyleType,
    PaperOrientationType,
    PaperSizeType,
    ParameterValueTypeType,
    PivotTableConditionalFormattingScopeRoleType,
    PivotTableMetricPlacementType,
    PivotTableSubtotalLevelType,
    PrimaryValueDisplayTypeType,
    ReferenceLineLabelHorizontalPositionType,
    ReferenceLineLabelVerticalPositionType,
    ReferenceLinePatternTypeType,
    ReferenceLineValueLabelRelativePositionType,
    RelativeDateTypeType,
    RelativeFontSizeType,
    ResizeOptionType,
    ResourceStatusType,
    RowLevelPermissionFormatVersionType,
    RowLevelPermissionPolicyType,
    SearchAnalysesPaginatorName,
    SearchDashboardsPaginatorName,
    SearchDataSetsPaginatorName,
    SearchDataSourcesPaginatorName,
    SectionPageBreakStatusType,
    SelectAllValueOptionsType,
    SelectedFieldOptionsType,
    SelectedTooltipTypeType,
    SheetContentTypeType,
    SheetControlDateTimePickerTypeType,
    SheetControlListTypeType,
    SheetControlSliderTypeType,
    SimpleNumericalAggregationFunctionType,
    SortDirectionType,
    StatusType,
    TableBorderStyleType,
    TableCellImageScalingConfigurationType,
    TableFieldIconSetTypeType,
    TableOrientationType,
    TableTotalsPlacementType,
    TableTotalsScrollStatusType,
    TargetVisualOptionsType,
    TemplateErrorTypeType,
    TextQualifierType,
    TextWrapType,
    ThemeErrorTypeType,
    ThemeTypeType,
    TimeGranularityType,
    TooltipTitleTypeType,
    TopBottomComputationTypeType,
    TopBottomSortOrderType,
    URLTargetConfigurationType,
    UserRoleType,
    ValueWhenUnsetOptionType,
    VerticalTextAlignmentType,
    VisibilityType,
    VisualCustomActionTriggerType,
    WidgetStatusType,
    WordCloudCloudLayoutType,
    WordCloudWordCasingType,
    WordCloudWordOrientationType,
    WordCloudWordPaddingType,
    WordCloudWordScalingType,
    QuickSightServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: AnalysisErrorTypeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_quicksight.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_quicksight.type_defs import (
    AccountCustomizationTypeDef,
    AccountInfoTypeDef,
    AccountSettingsTypeDef,
    ActiveIAMPolicyAssignmentTypeDef,
    AdHocFilteringOptionTypeDef,
    ColumnIdentifierTypeDef,
    AmazonElasticsearchParametersTypeDef,
    AmazonOpenSearchParametersTypeDef,
    CalculatedFieldTypeDef,
    DataSetIdentifierDeclarationTypeDef,
    EntityTypeDef,
    AnalysisSearchFilterTypeDef,
    DataSetReferenceTypeDef,
    AnalysisSummaryTypeDef,
    SheetTypeDef,
    AnchorDateConfigurationTypeDef,
    AnonymousUserDashboardEmbeddingConfigurationTypeDef,
    DashboardVisualIdTypeDef,
    AnonymousUserQSearchBarEmbeddingConfigurationTypeDef,
    ArcAxisDisplayRangeTypeDef,
    ArcConfigurationTypeDef,
    ArcOptionsTypeDef,
    AthenaParametersTypeDef,
    AuroraParametersTypeDef,
    AuroraPostgreSqlParametersTypeDef,
    AwsIotAnalyticsParametersTypeDef,
    DateAxisOptionsTypeDef,
    AxisDisplayMinMaxRangeTypeDef,
    AxisLinearScaleTypeDef,
    AxisLogarithmicScaleTypeDef,
    ItemsLimitConfigurationTypeDef,
    BinCountOptionsTypeDef,
    BinWidthOptionsTypeDef,
    BorderStyleTypeDef,
    BoxPlotStyleOptionsTypeDef,
    PaginationConfigurationTypeDef,
    CalculatedColumnTypeDef,
    CalculatedMeasureFieldTypeDef,
    CancelIngestionRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    CastColumnTypeOperationTypeDef,
    CustomFilterConfigurationTypeDef,
    CustomFilterListConfigurationTypeDef,
    FilterListConfigurationTypeDef,
    SimpleClusterMarkerTypeDef,
    DataColorTypeDef,
    ColumnDescriptionTypeDef,
    ColumnGroupColumnSchemaTypeDef,
    GeoSpatialColumnGroupTypeDef,
    ColumnLevelPermissionRuleTypeDef,
    ColumnSchemaTypeDef,
    ConditionalFormattingSolidColorTypeDef,
    ConditionalFormattingCustomIconOptionsTypeDef,
    ConditionalFormattingIconDisplayConfigurationTypeDef,
    ConditionalFormattingIconSetTypeDef,
    TagTypeDef,
    CreateAccountSubscriptionRequestRequestTypeDef,
    SignupResponseTypeDef,
    ResourcePermissionTypeDef,
    DataSetUsageConfigurationTypeDef,
    FieldFolderTypeDef,
    RowLevelPermissionDataSetTypeDef,
    SslPropertiesTypeDef,
    VpcConnectionPropertiesTypeDef,
    CreateFolderMembershipRequestRequestTypeDef,
    FolderMemberTypeDef,
    CreateGroupMembershipRequestRequestTypeDef,
    GroupMemberTypeDef,
    CreateGroupRequestRequestTypeDef,
    GroupTypeDef,
    CreateIAMPolicyAssignmentRequestRequestTypeDef,
    CreateIngestionRequestRequestTypeDef,
    CreateTemplateAliasRequestRequestTypeDef,
    TemplateAliasTypeDef,
    CreateThemeAliasRequestRequestTypeDef,
    ThemeAliasTypeDef,
    DecimalPlacesConfigurationTypeDef,
    NegativeValueConfigurationTypeDef,
    NullValueFormatConfigurationTypeDef,
    FilterOperationSelectedFieldsConfigurationTypeDef,
    LocalNavigationConfigurationTypeDef,
    CustomActionURLOperationTypeDef,
    CustomContentConfigurationTypeDef,
    CustomNarrativeOptionsTypeDef,
    CustomParameterValuesTypeDef,
    InputColumnTypeDef,
    ExportToCSVOptionTypeDef,
    SheetControlsOptionTypeDef,
    DashboardSearchFilterTypeDef,
    DashboardSummaryTypeDef,
    DashboardVersionSummaryTypeDef,
    ExportHiddenFieldsOptionTypeDef,
    DataColorPaletteTypeDef,
    DataPathLabelTypeTypeDef,
    FieldLabelTypeTypeDef,
    MaximumLabelTypeTypeDef,
    MinimumLabelTypeTypeDef,
    RangeEndsLabelTypeTypeDef,
    DataPathValueTypeDef,
    DataSetSearchFilterTypeDef,
    OutputColumnTypeDef,
    DataSourceErrorInfoTypeDef,
    DatabricksParametersTypeDef,
    ExasolParametersTypeDef,
    JiraParametersTypeDef,
    MariaDbParametersTypeDef,
    MySqlParametersTypeDef,
    OracleParametersTypeDef,
    PostgreSqlParametersTypeDef,
    PrestoParametersTypeDef,
    RdsParametersTypeDef,
    RedshiftParametersTypeDef,
    ServiceNowParametersTypeDef,
    SnowflakeParametersTypeDef,
    SparkParametersTypeDef,
    SqlServerParametersTypeDef,
    TeradataParametersTypeDef,
    TwitterParametersTypeDef,
    DataSourceSearchFilterTypeDef,
    DataSourceSummaryTypeDef,
    RollingDateConfigurationTypeDef,
    DateTimeValueWhenUnsetConfigurationTypeDef,
    DateTimeParameterTypeDef,
    DecimalValueWhenUnsetConfigurationTypeDef,
    DecimalParameterTypeDef,
    DeleteAccountCustomizationRequestRequestTypeDef,
    DeleteAccountSubscriptionRequestRequestTypeDef,
    DeleteAnalysisRequestRequestTypeDef,
    DeleteDashboardRequestRequestTypeDef,
    DeleteDataSetRequestRequestTypeDef,
    DeleteDataSourceRequestRequestTypeDef,
    DeleteFolderMembershipRequestRequestTypeDef,
    DeleteFolderRequestRequestTypeDef,
    DeleteGroupMembershipRequestRequestTypeDef,
    DeleteGroupRequestRequestTypeDef,
    DeleteIAMPolicyAssignmentRequestRequestTypeDef,
    DeleteNamespaceRequestRequestTypeDef,
    DeleteTemplateAliasRequestRequestTypeDef,
    DeleteTemplateRequestRequestTypeDef,
    DeleteThemeAliasRequestRequestTypeDef,
    DeleteThemeRequestRequestTypeDef,
    DeleteUserByPrincipalIdRequestRequestTypeDef,
    DeleteUserRequestRequestTypeDef,
    DescribeAccountCustomizationRequestRequestTypeDef,
    DescribeAccountSettingsRequestRequestTypeDef,
    DescribeAccountSubscriptionRequestRequestTypeDef,
    DescribeAnalysisDefinitionRequestRequestTypeDef,
    DescribeAnalysisPermissionsRequestRequestTypeDef,
    DescribeAnalysisRequestRequestTypeDef,
    DescribeDashboardDefinitionRequestRequestTypeDef,
    DescribeDashboardPermissionsRequestRequestTypeDef,
    DescribeDashboardRequestRequestTypeDef,
    DescribeDataSetPermissionsRequestRequestTypeDef,
    DescribeDataSetRequestRequestTypeDef,
    DescribeDataSourcePermissionsRequestRequestTypeDef,
    DescribeDataSourceRequestRequestTypeDef,
    DescribeFolderPermissionsRequestRequestTypeDef,
    DescribeFolderRequestRequestTypeDef,
    DescribeFolderResolvedPermissionsRequestRequestTypeDef,
    FolderTypeDef,
    DescribeGroupMembershipRequestRequestTypeDef,
    DescribeGroupRequestRequestTypeDef,
    DescribeIAMPolicyAssignmentRequestRequestTypeDef,
    IAMPolicyAssignmentTypeDef,
    DescribeIngestionRequestRequestTypeDef,
    DescribeIpRestrictionRequestRequestTypeDef,
    DescribeNamespaceRequestRequestTypeDef,
    DescribeTemplateAliasRequestRequestTypeDef,
    DescribeTemplateDefinitionRequestRequestTypeDef,
    DescribeTemplatePermissionsRequestRequestTypeDef,
    DescribeTemplateRequestRequestTypeDef,
    DescribeThemeAliasRequestRequestTypeDef,
    DescribeThemePermissionsRequestRequestTypeDef,
    DescribeThemeRequestRequestTypeDef,
    DescribeUserRequestRequestTypeDef,
    UserTypeDef,
    DonutCenterOptionsTypeDef,
    ListControlSelectAllOptionsTypeDef,
    ErrorInfoTypeDef,
    ExcludePeriodConfigurationTypeDef,
    FieldSortTypeDef,
    FieldTooltipItemTypeDef,
    GeospatialMapStyleOptionsTypeDef,
    FilterSelectableValuesTypeDef,
    SameSheetTargetVisualConfigurationTypeDef,
    FilterOperationTypeDef,
    FolderSearchFilterTypeDef,
    FolderSummaryTypeDef,
    FontSizeTypeDef,
    FontWeightTypeDef,
    FontTypeDef,
    TimeBasedForecastPropertiesTypeDef,
    WhatIfPointScenarioTypeDef,
    WhatIfRangeScenarioTypeDef,
    FreeFormLayoutScreenCanvasSizeOptionsTypeDef,
    FreeFormLayoutElementBackgroundStyleTypeDef,
    FreeFormLayoutElementBorderStyleTypeDef,
    LoadingAnimationTypeDef,
    SessionTagTypeDef,
    GeospatialCoordinateBoundsTypeDef,
    GetDashboardEmbedUrlRequestRequestTypeDef,
    GetSessionEmbedUrlRequestRequestTypeDef,
    TableBorderOptionsTypeDef,
    GradientStopTypeDef,
    GridLayoutScreenCanvasSizeOptionsTypeDef,
    GridLayoutElementTypeDef,
    GroupSearchFilterTypeDef,
    GutterStyleTypeDef,
    IAMPolicyAssignmentSummaryTypeDef,
    QueueInfoTypeDef,
    RowInfoTypeDef,
    IntegerValueWhenUnsetConfigurationTypeDef,
    IntegerParameterTypeDef,
    JoinKeyPropertiesTypeDef,
    ProgressBarOptionsTypeDef,
    SecondaryValueOptionsTypeDef,
    TrendArrowOptionsTypeDef,
    LineChartLineStyleSettingsTypeDef,
    LineChartMarkerStyleSettingsTypeDef,
    MissingDataConfigurationTypeDef,
    PaginatorConfigTypeDef,
    ListAnalysesRequestRequestTypeDef,
    ListControlSearchOptionsTypeDef,
    ListDashboardVersionsRequestRequestTypeDef,
    ListDashboardsRequestRequestTypeDef,
    ListDataSetsRequestRequestTypeDef,
    ListDataSourcesRequestRequestTypeDef,
    ListFolderMembersRequestRequestTypeDef,
    MemberIdArnPairTypeDef,
    ListFoldersRequestRequestTypeDef,
    ListGroupMembershipsRequestRequestTypeDef,
    ListGroupsRequestRequestTypeDef,
    ListIAMPolicyAssignmentsForUserRequestRequestTypeDef,
    ListIAMPolicyAssignmentsRequestRequestTypeDef,
    ListIngestionsRequestRequestTypeDef,
    ListNamespacesRequestRequestTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTemplateAliasesRequestRequestTypeDef,
    ListTemplateVersionsRequestRequestTypeDef,
    TemplateVersionSummaryTypeDef,
    ListTemplatesRequestRequestTypeDef,
    TemplateSummaryTypeDef,
    ListThemeAliasesRequestRequestTypeDef,
    ListThemeVersionsRequestRequestTypeDef,
    ThemeVersionSummaryTypeDef,
    ListThemesRequestRequestTypeDef,
    ThemeSummaryTypeDef,
    ListUserGroupsRequestRequestTypeDef,
    ListUsersRequestRequestTypeDef,
    LongFormatTextTypeDef,
    ManifestFileLocationTypeDef,
    MarginStyleTypeDef,
    NamespaceErrorTypeDef,
    NumericRangeFilterValueTypeDef,
    ThousandSeparatorOptionsTypeDef,
    PercentileAggregationTypeDef,
    StringParameterTypeDef,
    PercentVisibleRangeTypeDef,
    PivotTableConditionalFormattingScopeTypeDef,
    PivotTablePaginatedReportOptionsTypeDef,
    PivotTableFieldOptionTypeDef,
    PivotTableFieldSubtotalOptionsTypeDef,
    RowAlternateColorOptionsTypeDef,
    ProjectOperationTypeDef,
    ReferenceLineCustomLabelConfigurationTypeDef,
    ReferenceLineStaticDataConfigurationTypeDef,
    ReferenceLineStyleConfigurationTypeDef,
    RegisterUserRequestRequestTypeDef,
    RegisteredUserDashboardEmbeddingConfigurationTypeDef,
    RegisteredUserQSearchBarEmbeddingConfigurationTypeDef,
    RegisteredUserQuickSightConsoleEmbeddingConfigurationTypeDef,
    RenameColumnOperationTypeDef,
    RestoreAnalysisRequestRequestTypeDef,
    RowLevelPermissionTagRuleTypeDef,
    UploadSettingsTypeDef,
    SectionAfterPageBreakTypeDef,
    SpacingTypeDef,
    SheetVisualScopingConfigurationTypeDef,
    SheetTextBoxTypeDef,
    SheetElementConfigurationOverridesTypeDef,
    ShortFormatTextTypeDef,
    StringValueWhenUnsetConfigurationTypeDef,
    TableCellImageSizingConfigurationTypeDef,
    TablePaginatedReportOptionsTypeDef,
    TableFieldCustomIconContentTypeDef,
    TemplateSourceTemplateTypeDef,
    TextControlPlaceholderOptionsTypeDef,
    UIColorPaletteTypeDef,
    ThemeErrorTypeDef,
    UntagColumnOperationTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateAccountSettingsRequestRequestTypeDef,
    UpdateDashboardPublishedVersionRequestRequestTypeDef,
    UpdateFolderRequestRequestTypeDef,
    UpdateGroupRequestRequestTypeDef,
    UpdateIAMPolicyAssignmentRequestRequestTypeDef,
    UpdateIpRestrictionRequestRequestTypeDef,
    UpdatePublicSharingSettingsRequestRequestTypeDef,
    UpdateTemplateAliasRequestRequestTypeDef,
    UpdateThemeAliasRequestRequestTypeDef,
    UpdateUserRequestRequestTypeDef,
    WaterfallChartOptionsTypeDef,
    WordCloudOptionsTypeDef,
    UpdateAccountCustomizationRequestRequestTypeDef,
    AxisLabelReferenceOptionsTypeDef,
    CascadingControlSourceTypeDef,
    CategoryDrillDownFilterTypeDef,
    ContributionAnalysisDefaultTypeDef,
    DynamicDefaultValueTypeDef,
    NumericEqualityDrillDownFilterTypeDef,
    ParameterSelectableValuesTypeDef,
    TimeEqualityFilterTypeDef,
    TimeRangeDrillDownFilterTypeDef,
    AnalysisErrorTypeDef,
    DashboardErrorTypeDef,
    TemplateErrorTypeDef,
    SearchAnalysesRequestRequestTypeDef,
    AnalysisSourceTemplateTypeDef,
    DashboardSourceTemplateTypeDef,
    TemplateSourceAnalysisTypeDef,
    AnonymousUserDashboardVisualEmbeddingConfigurationTypeDef,
    RegisteredUserDashboardVisualEmbeddingConfigurationTypeDef,
    ArcAxisConfigurationTypeDef,
    AxisDisplayRangeTypeDef,
    AxisScaleTypeDef,
    HistogramBinOptionsTypeDef,
    TileStyleTypeDef,
    BoxPlotOptionsTypeDef,
    CreateColumnsOperationTypeDef,
    CancelIngestionResponseTypeDef,
    CreateAccountCustomizationResponseTypeDef,
    CreateAnalysisResponseTypeDef,
    CreateDashboardResponseTypeDef,
    CreateDataSetResponseTypeDef,
    CreateDataSourceResponseTypeDef,
    CreateFolderResponseTypeDef,
    CreateIAMPolicyAssignmentResponseTypeDef,
    CreateIngestionResponseTypeDef,
    CreateNamespaceResponseTypeDef,
    CreateTemplateResponseTypeDef,
    CreateThemeResponseTypeDef,
    DeleteAccountCustomizationResponseTypeDef,
    DeleteAccountSubscriptionResponseTypeDef,
    DeleteAnalysisResponseTypeDef,
    DeleteDashboardResponseTypeDef,
    DeleteDataSetResponseTypeDef,
    DeleteDataSourceResponseTypeDef,
    DeleteFolderMembershipResponseTypeDef,
    DeleteFolderResponseTypeDef,
    DeleteGroupMembershipResponseTypeDef,
    DeleteGroupResponseTypeDef,
    DeleteIAMPolicyAssignmentResponseTypeDef,
    DeleteNamespaceResponseTypeDef,
    DeleteTemplateAliasResponseTypeDef,
    DeleteTemplateResponseTypeDef,
    DeleteThemeAliasResponseTypeDef,
    DeleteThemeResponseTypeDef,
    DeleteUserByPrincipalIdResponseTypeDef,
    DeleteUserResponseTypeDef,
    DescribeAccountCustomizationResponseTypeDef,
    DescribeAccountSettingsResponseTypeDef,
    DescribeAccountSubscriptionResponseTypeDef,
    DescribeIpRestrictionResponseTypeDef,
    GenerateEmbedUrlForAnonymousUserResponseTypeDef,
    GenerateEmbedUrlForRegisteredUserResponseTypeDef,
    GetDashboardEmbedUrlResponseTypeDef,
    GetSessionEmbedUrlResponseTypeDef,
    ListAnalysesResponseTypeDef,
    ListIAMPolicyAssignmentsForUserResponseTypeDef,
    RestoreAnalysisResponseTypeDef,
    SearchAnalysesResponseTypeDef,
    TagResourceResponseTypeDef,
    UntagResourceResponseTypeDef,
    UpdateAccountCustomizationResponseTypeDef,
    UpdateAccountSettingsResponseTypeDef,
    UpdateAnalysisResponseTypeDef,
    UpdateDashboardPublishedVersionResponseTypeDef,
    UpdateDashboardResponseTypeDef,
    UpdateDataSetPermissionsResponseTypeDef,
    UpdateDataSetResponseTypeDef,
    UpdateDataSourcePermissionsResponseTypeDef,
    UpdateDataSourceResponseTypeDef,
    UpdateFolderResponseTypeDef,
    UpdateIAMPolicyAssignmentResponseTypeDef,
    UpdateIpRestrictionResponseTypeDef,
    UpdatePublicSharingSettingsResponseTypeDef,
    UpdateTemplateResponseTypeDef,
    UpdateThemeResponseTypeDef,
    CategoryFilterConfigurationTypeDef,
    ClusterMarkerTypeDef,
    ColorScaleTypeDef,
    ColumnTagTypeDef,
    ColumnGroupSchemaTypeDef,
    ColumnGroupTypeDef,
    DataSetSchemaTypeDef,
    ConditionalFormattingCustomIconConditionTypeDef,
    CreateAccountCustomizationRequestRequestTypeDef,
    CreateNamespaceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    TagResourceRequestRequestTypeDef,
    CreateAccountSubscriptionResponseTypeDef,
    CreateFolderRequestRequestTypeDef,
    DescribeAnalysisPermissionsResponseTypeDef,
    DescribeDataSetPermissionsResponseTypeDef,
    DescribeDataSourcePermissionsResponseTypeDef,
    DescribeFolderPermissionsResponseTypeDef,
    DescribeFolderResolvedPermissionsResponseTypeDef,
    DescribeTemplatePermissionsResponseTypeDef,
    DescribeThemePermissionsResponseTypeDef,
    LinkSharingConfigurationTypeDef,
    UpdateAnalysisPermissionsRequestRequestTypeDef,
    UpdateAnalysisPermissionsResponseTypeDef,
    UpdateDashboardPermissionsRequestRequestTypeDef,
    UpdateDataSetPermissionsRequestRequestTypeDef,
    UpdateDataSourcePermissionsRequestRequestTypeDef,
    UpdateFolderPermissionsRequestRequestTypeDef,
    UpdateFolderPermissionsResponseTypeDef,
    UpdateTemplatePermissionsRequestRequestTypeDef,
    UpdateTemplatePermissionsResponseTypeDef,
    UpdateThemePermissionsRequestRequestTypeDef,
    UpdateThemePermissionsResponseTypeDef,
    DataSetSummaryTypeDef,
    CreateFolderMembershipResponseTypeDef,
    CreateGroupMembershipResponseTypeDef,
    DescribeGroupMembershipResponseTypeDef,
    ListGroupMembershipsResponseTypeDef,
    CreateGroupResponseTypeDef,
    DescribeGroupResponseTypeDef,
    ListGroupsResponseTypeDef,
    ListUserGroupsResponseTypeDef,
    SearchGroupsResponseTypeDef,
    UpdateGroupResponseTypeDef,
    CreateTemplateAliasResponseTypeDef,
    DescribeTemplateAliasResponseTypeDef,
    ListTemplateAliasesResponseTypeDef,
    UpdateTemplateAliasResponseTypeDef,
    CreateThemeAliasResponseTypeDef,
    DescribeThemeAliasResponseTypeDef,
    ListThemeAliasesResponseTypeDef,
    UpdateThemeAliasResponseTypeDef,
    CustomActionNavigationOperationTypeDef,
    CustomValuesConfigurationTypeDef,
    CustomSqlTypeDef,
    RelationalTableTypeDef,
    SearchDashboardsRequestRequestTypeDef,
    ListDashboardsResponseTypeDef,
    SearchDashboardsResponseTypeDef,
    ListDashboardVersionsResponseTypeDef,
    DashboardVisualPublishOptionsTypeDef,
    DataLabelTypeTypeDef,
    DataPathColorTypeDef,
    DataPathSortTypeDef,
    PivotTableDataPathOptionTypeDef,
    SearchDataSetsRequestRequestTypeDef,
    SearchDataSourcesRequestRequestTypeDef,
    SearchDataSourcesResponseTypeDef,
    TimeRangeFilterValueTypeDef,
    DescribeFolderResponseTypeDef,
    DescribeIAMPolicyAssignmentResponseTypeDef,
    DescribeUserResponseTypeDef,
    ListUsersResponseTypeDef,
    RegisterUserResponseTypeDef,
    UpdateUserResponseTypeDef,
    DonutOptionsTypeDef,
    RelativeDatesFilterTypeDef,
    FilterOperationTargetVisualsConfigurationTypeDef,
    SearchFoldersRequestRequestTypeDef,
    ListFoldersResponseTypeDef,
    SearchFoldersResponseTypeDef,
    FontConfigurationTypeDef,
    TypographyTypeDef,
    ForecastScenarioTypeDef,
    FreeFormLayoutCanvasSizeOptionsTypeDef,
    GeospatialWindowOptionsTypeDef,
    TableSideBorderOptionsTypeDef,
    GradientColorTypeDef,
    GridLayoutCanvasSizeOptionsTypeDef,
    SearchGroupsRequestRequestTypeDef,
    ListIAMPolicyAssignmentsResponseTypeDef,
    IngestionTypeDef,
    JoinInstructionTypeDef,
    LineChartDefaultSeriesSettingsTypeDef,
    LineChartSeriesSettingsTypeDef,
    ListAnalysesRequestListAnalysesPaginateTypeDef,
    ListDashboardVersionsRequestListDashboardVersionsPaginateTypeDef,
    ListDashboardsRequestListDashboardsPaginateTypeDef,
    ListDataSetsRequestListDataSetsPaginateTypeDef,
    ListDataSourcesRequestListDataSourcesPaginateTypeDef,
    ListIngestionsRequestListIngestionsPaginateTypeDef,
    ListNamespacesRequestListNamespacesPaginateTypeDef,
    ListTemplateAliasesRequestListTemplateAliasesPaginateTypeDef,
    ListTemplateVersionsRequestListTemplateVersionsPaginateTypeDef,
    ListTemplatesRequestListTemplatesPaginateTypeDef,
    ListThemeVersionsRequestListThemeVersionsPaginateTypeDef,
    ListThemesRequestListThemesPaginateTypeDef,
    SearchAnalysesRequestSearchAnalysesPaginateTypeDef,
    SearchDashboardsRequestSearchDashboardsPaginateTypeDef,
    SearchDataSetsRequestSearchDataSetsPaginateTypeDef,
    SearchDataSourcesRequestSearchDataSourcesPaginateTypeDef,
    ListFolderMembersResponseTypeDef,
    ListTemplateVersionsResponseTypeDef,
    ListTemplatesResponseTypeDef,
    ListThemeVersionsResponseTypeDef,
    ListThemesResponseTypeDef,
    VisualSubtitleLabelOptionsTypeDef,
    S3ParametersTypeDef,
    TileLayoutStyleTypeDef,
    NamespaceInfoV2TypeDef,
    NumericSeparatorConfigurationTypeDef,
    NumericalAggregationFunctionTypeDef,
    ParametersTypeDef,
    VisibleRangeOptionsTypeDef,
    RowLevelPermissionTagConfigurationTypeDef,
    S3SourceTypeDef,
    SectionPageBreakConfigurationTypeDef,
    SectionBasedLayoutPaperCanvasSizeOptionsTypeDef,
    SectionStyleTypeDef,
    SelectedSheetsFilterScopeConfigurationTypeDef,
    SheetElementRenderingRuleTypeDef,
    VisualTitleLabelOptionsTypeDef,
    TableFieldImageConfigurationTypeDef,
    CascadingControlConfigurationTypeDef,
    DateTimeDefaultValuesTypeDef,
    DecimalDefaultValuesTypeDef,
    IntegerDefaultValuesTypeDef,
    StringDefaultValuesTypeDef,
    DrillDownFilterTypeDef,
    AnalysisTypeDef,
    DashboardVersionTypeDef,
    AnalysisSourceEntityTypeDef,
    DashboardSourceEntityTypeDef,
    TemplateSourceEntityTypeDef,
    AnonymousUserEmbeddingExperienceConfigurationTypeDef,
    RegisteredUserEmbeddingExperienceConfigurationTypeDef,
    NumericAxisOptionsTypeDef,
    CategoryFilterTypeDef,
    ClusterMarkerConfigurationTypeDef,
    TagColumnOperationTypeDef,
    DataSetConfigurationTypeDef,
    ConditionalFormattingIconTypeDef,
    DescribeDashboardPermissionsResponseTypeDef,
    UpdateDashboardPermissionsResponseTypeDef,
    ListDataSetsResponseTypeDef,
    SearchDataSetsResponseTypeDef,
    DestinationParameterValueConfigurationTypeDef,
    DashboardPublishOptionsTypeDef,
    VisualPaletteTypeDef,
    PivotTableFieldOptionsTypeDef,
    TimeRangeFilterTypeDef,
    CustomActionFilterOperationTypeDef,
    AxisLabelOptionsTypeDef,
    DataLabelOptionsTypeDef,
    FunnelChartDataLabelOptionsTypeDef,
    LabelOptionsTypeDef,
    PanelTitleOptionsTypeDef,
    TableFieldCustomTextContentTypeDef,
    ForecastConfigurationTypeDef,
    DefaultFreeFormLayoutConfigurationTypeDef,
    GlobalTableBorderOptionsTypeDef,
    ConditionalFormattingGradientColorTypeDef,
    DefaultGridLayoutConfigurationTypeDef,
    GridLayoutConfigurationTypeDef,
    DescribeIngestionResponseTypeDef,
    ListIngestionsResponseTypeDef,
    LogicalTableSourceTypeDef,
    DataFieldSeriesItemTypeDef,
    FieldSeriesItemTypeDef,
    DataSourceParametersTypeDef,
    SheetStyleTypeDef,
    DescribeNamespaceResponseTypeDef,
    ListNamespacesResponseTypeDef,
    CurrencyDisplayFormatConfigurationTypeDef,
    NumberDisplayFormatConfigurationTypeDef,
    PercentageDisplayFormatConfigurationTypeDef,
    AggregationFunctionTypeDef,
    ScrollBarOptionsTypeDef,
    PhysicalTableTypeDef,
    SectionBasedLayoutCanvasSizeOptionsTypeDef,
    FilterScopeConfigurationTypeDef,
    FreeFormLayoutElementTypeDef,
    DateTimeParameterDeclarationTypeDef,
    DecimalParameterDeclarationTypeDef,
    IntegerParameterDeclarationTypeDef,
    StringParameterDeclarationTypeDef,
    DateTimeHierarchyTypeDef,
    ExplicitHierarchyTypeDef,
    PredefinedHierarchyTypeDef,
    DescribeAnalysisResponseTypeDef,
    DashboardTypeDef,
    GenerateEmbedUrlForAnonymousUserRequestRequestTypeDef,
    GenerateEmbedUrlForRegisteredUserRequestRequestTypeDef,
    AxisDataOptionsTypeDef,
    GeospatialPointStyleOptionsTypeDef,
    TransformOperationTypeDef,
    TemplateVersionTypeDef,
    SetParameterValueConfigurationTypeDef,
    ChartAxisLabelOptionsTypeDef,
    AxisTickLabelOptionsTypeDef,
    DateTimePickerControlDisplayOptionsTypeDef,
    DropDownControlDisplayOptionsTypeDef,
    LegendOptionsTypeDef,
    ListControlDisplayOptionsTypeDef,
    RelativeDateTimeControlDisplayOptionsTypeDef,
    SliderControlDisplayOptionsTypeDef,
    TextAreaControlDisplayOptionsTypeDef,
    TextFieldControlDisplayOptionsTypeDef,
    PanelConfigurationTypeDef,
    TableFieldLinkContentConfigurationTypeDef,
    TableCellStyleTypeDef,
    ConditionalFormattingColorTypeDef,
    DefaultInteractiveLayoutConfigurationTypeDef,
    SheetControlLayoutConfigurationTypeDef,
    SeriesItemTypeDef,
    CredentialPairTypeDef,
    DataSourceTypeDef,
    ThemeConfigurationTypeDef,
    ComparisonFormatConfigurationTypeDef,
    NumericFormatConfigurationTypeDef,
    AggregationSortConfigurationTypeDef,
    ColumnSortTypeDef,
    ColumnTooltipItemTypeDef,
    NumericEqualityFilterTypeDef,
    NumericRangeFilterTypeDef,
    ReferenceLineDynamicDataConfigurationTypeDef,
    DefaultSectionBasedLayoutConfigurationTypeDef,
    FreeFormLayoutConfigurationTypeDef,
    FreeFormSectionLayoutConfigurationTypeDef,
    ParameterDeclarationTypeDef,
    ColumnHierarchyTypeDef,
    DescribeDashboardResponseTypeDef,
    LogicalTableTypeDef,
    TemplateTypeDef,
    CustomActionSetParametersOperationTypeDef,
    AxisDisplayOptionsTypeDef,
    FilterDateTimePickerControlTypeDef,
    ParameterDateTimePickerControlTypeDef,
    FilterDropDownControlTypeDef,
    ParameterDropDownControlTypeDef,
    FilterListControlTypeDef,
    ParameterListControlTypeDef,
    FilterRelativeDateTimeControlTypeDef,
    FilterSliderControlTypeDef,
    ParameterSliderControlTypeDef,
    FilterTextAreaControlTypeDef,
    ParameterTextAreaControlTypeDef,
    FilterTextFieldControlTypeDef,
    ParameterTextFieldControlTypeDef,
    SmallMultiplesOptionsTypeDef,
    TableFieldLinkConfigurationTypeDef,
    PivotTableOptionsTypeDef,
    PivotTotalOptionsTypeDef,
    SubtotalOptionsTypeDef,
    TableOptionsTypeDef,
    TotalOptionsTypeDef,
    GaugeChartArcConditionalFormattingTypeDef,
    GaugeChartPrimaryValueConditionalFormattingTypeDef,
    KPIPrimaryValueConditionalFormattingTypeDef,
    KPIProgressBarConditionalFormattingTypeDef,
    ShapeConditionalFormatTypeDef,
    TableRowConditionalFormattingTypeDef,
    TextConditionalFormatTypeDef,
    SheetControlLayoutTypeDef,
    DataSourceCredentialsTypeDef,
    DescribeDataSourceResponseTypeDef,
    ListDataSourcesResponseTypeDef,
    CreateThemeRequestRequestTypeDef,
    ThemeVersionTypeDef,
    UpdateThemeRequestRequestTypeDef,
    ComparisonConfigurationTypeDef,
    DateTimeFormatConfigurationTypeDef,
    NumberFormatConfigurationTypeDef,
    ReferenceLineValueLabelConfigurationTypeDef,
    StringFormatConfigurationTypeDef,
    TopBottomFilterTypeDef,
    FieldSortOptionsTypeDef,
    PivotTableSortByTypeDef,
    TooltipItemTypeDef,
    ReferenceLineDataConfigurationTypeDef,
    DefaultPaginatedLayoutConfigurationTypeDef,
    SectionLayoutConfigurationTypeDef,
    CreateDataSetRequestRequestTypeDef,
    DataSetTypeDef,
    UpdateDataSetRequestRequestTypeDef,
    DescribeTemplateResponseTypeDef,
    VisualCustomActionOperationTypeDef,
    LineSeriesAxisDisplayOptionsTypeDef,
    FilterControlTypeDef,
    ParameterControlTypeDef,
    TableFieldURLConfigurationTypeDef,
    PivotTableTotalOptionsTypeDef,
    GaugeChartConditionalFormattingOptionTypeDef,
    KPIConditionalFormattingOptionTypeDef,
    FilledMapShapeConditionalFormattingTypeDef,
    PivotTableCellConditionalFormattingTypeDef,
    TableCellConditionalFormattingTypeDef,
    CreateDataSourceRequestRequestTypeDef,
    UpdateDataSourceRequestRequestTypeDef,
    ThemeTypeDef,
    GaugeChartOptionsTypeDef,
    KPIOptionsTypeDef,
    DateDimensionFieldTypeDef,
    DateMeasureFieldTypeDef,
    NumericalDimensionFieldTypeDef,
    NumericalMeasureFieldTypeDef,
    ReferenceLineLabelConfigurationTypeDef,
    CategoricalDimensionFieldTypeDef,
    CategoricalMeasureFieldTypeDef,
    FormatConfigurationTypeDef,
    FilterTypeDef,
    BarChartSortConfigurationTypeDef,
    BoxPlotSortConfigurationTypeDef,
    ComboChartSortConfigurationTypeDef,
    FilledMapSortConfigurationTypeDef,
    FunnelChartSortConfigurationTypeDef,
    HeatMapSortConfigurationTypeDef,
    KPISortConfigurationTypeDef,
    LineChartSortConfigurationTypeDef,
    PieChartSortConfigurationTypeDef,
    SankeyDiagramSortConfigurationTypeDef,
    TableSortConfigurationTypeDef,
    TreeMapSortConfigurationTypeDef,
    WaterfallChartSortConfigurationTypeDef,
    WordCloudSortConfigurationTypeDef,
    PivotFieldSortOptionsTypeDef,
    FieldBasedTooltipTypeDef,
    DefaultNewSheetConfigurationTypeDef,
    BodySectionContentTypeDef,
    HeaderFooterSectionConfigurationTypeDef,
    DescribeDataSetResponseTypeDef,
    VisualCustomActionTypeDef,
    TableFieldOptionTypeDef,
    GaugeChartConditionalFormattingTypeDef,
    KPIConditionalFormattingTypeDef,
    FilledMapConditionalFormattingOptionTypeDef,
    PivotTableConditionalFormattingOptionTypeDef,
    TableConditionalFormattingOptionTypeDef,
    DescribeThemeResponseTypeDef,
    ReferenceLineTypeDef,
    DimensionFieldTypeDef,
    MeasureFieldTypeDef,
    ColumnConfigurationTypeDef,
    UnaggregatedFieldTypeDef,
    FilterGroupTypeDef,
    PivotTableSortConfigurationTypeDef,
    TooltipOptionsTypeDef,
    AnalysisDefaultsTypeDef,
    BodySectionConfigurationTypeDef,
    CustomContentVisualTypeDef,
    EmptyVisualTypeDef,
    TableFieldOptionsTypeDef,
    FilledMapConditionalFormattingTypeDef,
    PivotTableConditionalFormattingTypeDef,
    TableConditionalFormattingTypeDef,
    UniqueValuesComputationTypeDef,
    BarChartAggregatedFieldWellsTypeDef,
    BoxPlotAggregatedFieldWellsTypeDef,
    ComboChartAggregatedFieldWellsTypeDef,
    FilledMapAggregatedFieldWellsTypeDef,
    ForecastComputationTypeDef,
    FunnelChartAggregatedFieldWellsTypeDef,
    GaugeChartFieldWellsTypeDef,
    GeospatialMapAggregatedFieldWellsTypeDef,
    GrowthRateComputationTypeDef,
    HeatMapAggregatedFieldWellsTypeDef,
    HistogramAggregatedFieldWellsTypeDef,
    KPIFieldWellsTypeDef,
    LineChartAggregatedFieldWellsTypeDef,
    MaximumMinimumComputationTypeDef,
    MetricComparisonComputationTypeDef,
    PeriodOverPeriodComputationTypeDef,
    PeriodToDateComputationTypeDef,
    PieChartAggregatedFieldWellsTypeDef,
    PivotTableAggregatedFieldWellsTypeDef,
    SankeyDiagramAggregatedFieldWellsTypeDef,
    ScatterPlotCategoricallyAggregatedFieldWellsTypeDef,
    ScatterPlotUnaggregatedFieldWellsTypeDef,
    TableAggregatedFieldWellsTypeDef,
    TopBottomMoversComputationTypeDef,
    TopBottomRankedComputationTypeDef,
    TotalAggregationComputationTypeDef,
    TreeMapAggregatedFieldWellsTypeDef,
    WaterfallChartAggregatedFieldWellsTypeDef,
    WordCloudAggregatedFieldWellsTypeDef,
    TableUnaggregatedFieldWellsTypeDef,
    SectionBasedLayoutConfigurationTypeDef,
    BarChartFieldWellsTypeDef,
    BoxPlotFieldWellsTypeDef,
    ComboChartFieldWellsTypeDef,
    FilledMapFieldWellsTypeDef,
    FunnelChartFieldWellsTypeDef,
    GaugeChartConfigurationTypeDef,
    GeospatialMapFieldWellsTypeDef,
    HeatMapFieldWellsTypeDef,
    HistogramFieldWellsTypeDef,
    KPIConfigurationTypeDef,
    LineChartFieldWellsTypeDef,
    PieChartFieldWellsTypeDef,
    PivotTableFieldWellsTypeDef,
    SankeyDiagramFieldWellsTypeDef,
    ScatterPlotFieldWellsTypeDef,
    ComputationTypeDef,
    TreeMapFieldWellsTypeDef,
    WaterfallChartFieldWellsTypeDef,
    WordCloudFieldWellsTypeDef,
    TableFieldWellsTypeDef,
    LayoutConfigurationTypeDef,
    BarChartConfigurationTypeDef,
    BoxPlotChartConfigurationTypeDef,
    ComboChartConfigurationTypeDef,
    FilledMapConfigurationTypeDef,
    FunnelChartConfigurationTypeDef,
    GaugeChartVisualTypeDef,
    GeospatialMapConfigurationTypeDef,
    HeatMapConfigurationTypeDef,
    HistogramConfigurationTypeDef,
    KPIVisualTypeDef,
    LineChartConfigurationTypeDef,
    PieChartConfigurationTypeDef,
    PivotTableConfigurationTypeDef,
    SankeyDiagramChartConfigurationTypeDef,
    ScatterPlotConfigurationTypeDef,
    InsightConfigurationTypeDef,
    TreeMapConfigurationTypeDef,
    WaterfallChartConfigurationTypeDef,
    WordCloudChartConfigurationTypeDef,
    TableConfigurationTypeDef,
    LayoutTypeDef,
    BarChartVisualTypeDef,
    BoxPlotVisualTypeDef,
    ComboChartVisualTypeDef,
    FilledMapVisualTypeDef,
    FunnelChartVisualTypeDef,
    GeospatialMapVisualTypeDef,
    HeatMapVisualTypeDef,
    HistogramVisualTypeDef,
    LineChartVisualTypeDef,
    PieChartVisualTypeDef,
    PivotTableVisualTypeDef,
    SankeyDiagramVisualTypeDef,
    ScatterPlotVisualTypeDef,
    InsightVisualTypeDef,
    TreeMapVisualTypeDef,
    WaterfallVisualTypeDef,
    WordCloudVisualTypeDef,
    TableVisualTypeDef,
    VisualTypeDef,
    SheetDefinitionTypeDef,
    AnalysisDefinitionTypeDef,
    DashboardVersionDefinitionTypeDef,
    TemplateVersionDefinitionTypeDef,
    CreateAnalysisRequestRequestTypeDef,
    DescribeAnalysisDefinitionResponseTypeDef,
    UpdateAnalysisRequestRequestTypeDef,
    CreateDashboardRequestRequestTypeDef,
    DescribeDashboardDefinitionResponseTypeDef,
    UpdateDashboardRequestRequestTypeDef,
    CreateTemplateRequestRequestTypeDef,
    DescribeTemplateDefinitionResponseTypeDef,
    UpdateTemplateRequestRequestTypeDef,
)


def get_structure() -> AccountCustomizationTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for `boto3`
updates. It delivers a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`mypy-boto3-quicksight` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[boto3 docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_quicksight/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
